@@ -1,7 +1,7 @@
 package Data::Format::Pretty::Console;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,6 @@ use warnings;
 use experimental 'smartmatch';
 use Log::Any::IfLOG '$log';
 
-use Data::Unixish::Apply;
 use Scalar::Util qw(blessed);
 use Text::ANSITable;
 use YAML::Any;
@@ -486,7 +485,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-This document describes version 0.34 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2015-08-17.
+This document describes version 0.35 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2015-10-20.
 
 =head1 SYNOPSIS
 
@@ -708,7 +707,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Forma
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Format-Pretty-Console>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Format-Pretty-Console>.
 
 =head1 BUGS
 
